#!/bin/sh
# $Id: jailup.sh,v 1.6 2003/05/03 03:17:49 babolo Exp $
export PATH=/bin

if  [ -r /etc/defaults/rc.conf ]; then
    . /etc/defaults/rc.conf
    source_rc_confs
elif [ -r /etc/rc.conf ]; then
    . /etc/rc.conf
fi

case ${kern_securelevel_enable} in
[Yy][Ee][Ss])
    ;;
*)
#   exit
    ;;
esac

if [ -z "${JAILUP_CONF}" ]; then
    export JAILUP_CONF=%%CONFDIR%%/jailup.conf
fi
. ${JAILUP_CONF}

echo ' jailup'
case ${1} in
start)
    shift
    ${PREFIX}/sbin/jailupctl restop "$@" > /dev/null 2>&1
    ${PREFIX}/sbin/jailupctl start  "$@"
    ;;
*)
    ${PREFIX}/sbin/jailupctl "$@"
    ;;
esac
